==> abiword_2.8.2.orig.tar.gz: abiword-2.8.2/src/wp/ap/xp/ap_Toolbar_Icons_All.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */


/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

/*****************************************************************
******************************************************************
** FOR EACH ICON YOU ADD, ADD IT TO BOTH SECTIONS OF THIS FILE. **
******************************************************************
*****************************************************************/

#ifndef AP_TOOLBAR_ICONS_ALL_H

#	define AP_TOOLBAR_ICONS_ALL_H

	// Include each toolbar icon that we want to build.

#   include "tb_LineTop.xpm"
#   include "tb_LineBottom.xpm"
#   include "tb_LineLeft.xpm"
#   include "tb_LineRight.xpm"
#   include "tb_LineNone.xpm"
#   include "tb_LineAll.xpm"
#   include "tb_MergeAbove.xpm"
#   include "tb_MergeBelow.xpm"
#   include "tb_MergeLeft.xpm"
#   include "tb_MergeRight.xpm"
#   include "tb_SplitAbove.xpm"
#   include "tb_SplitVertMid.xpm"
#   include "tb_SplitBelow.xpm"
#   include "tb_SplitLeft.xpm"
#   include "tb_SplitHoriMid.xpm"
#   include "tb_SplitRight.xpm"
#	include "tb_text_center.xpm"
#	include "tb_text_justify.xpm"
#	include "tb_text_align_left.xpm"
#	include "tb_text_align_right.xpm"
#	include "tb_text_bold.xpm"
#	include "tb_text_font.xpm"
#	include "tb_text_italic.xpm"
#	include "tb_text_strikeout.xpm"
#	include "tb_text_underline.xpm"
#	include "tb_text_overline.xpm"
#	include "tb_text_topline.xpm"
#	include "tb_text_bottomline.xpm"
#	include "tb_text_superscript.xpm"
#	include "tb_text_subscript.xpm"
#	include "tb_help.xpm"
#	include "tb_text_direction_rtl.xpm"
#	include "tb_text_direction_ltr.xpm"
#	include "tb_text_dom_direction_rtl.xpm"
#	include "tb_symbol.xpm"
#	include "tb_para_0before.xpm"
#	include "tb_para_12before.xpm"
#	include "tb_1column.xpm"
#	include "tb_2column.xpm"
#	include "tb_3column.xpm"
#	include "tb_line_single_space.xpm"
#	include "tb_line_middle_space.xpm"
#	include "tb_line_double_space.xpm"
#	include "tb_copy.xpm"
#	include "tb_cut.xpm"
#	include "tb_edit.xpm"
#	include "tb_new.xpm"
#	include "tb_open.xpm"
#	include "tb_paste.xpm"
#	include "tb_print.xpm"
#	include "tb_print_preview.xpm"
#	include "tb_redo.xpm"
#	include "tb_save.xpm"
#	include "tb_save_as.xpm"
#	include "tb_undo.xpm"
#	include "tb_todo.xpm"
#	include "tb_lists_bullets.xpm"
#	include "tb_lists_numbers.xpm"
#	include "tb_text_indent.xpm"
#	include "tb_text_unindent.xpm"
#	include "tb_spellcheck.xpm"
#	include "tb_insert_graphic.xpm"
#	include "tb_remove_graphic.xpm"
#	include "tb_view_showpara.xpm"
#	include "tb_text_fgcolor.xpm"
#	include "tb_text_bgcolor.xpm"
#	include "tb_edit_editheader.xpm"
#	include "tb_edit_editfooter.xpm"
#	include "tb_edit_removeheader.xpm"
#	include "tb_edit_removefooter.xpm"
#	include "tb_anchor.xpm"
#	include "tb_hyperlink.xpm"
#	include "tb_smiley.xpm"

#	include "tb_script_play.xpm"
#	include "tb_stock_paint.xpm"

#	include "tb_insert_table.xpm"
#	include "tb_add_row.xpm"
#	include "tb_add_column.xpm"
#	include "tb_delete_row.xpm"
#	include "tb_delete_column.xpm"
#	include "tb_merge_cells.xpm"
#	include "tb_split_cells.xpm"
#	include "tb_transparent.xpm"
#	include "tb_WrapButton.xpm"
#       include "tb_stock_font.xpm"
#	include "tb_view_full_screen.xpm"

	// ... add new icons here (don't forget to add below the #else) ...

#	include "menu_copy.xpm"
#	include "menu_cut.xpm"
#	include "menu_exit.xpm"
#	include "menu_new.xpm"
#	include "menu_open.xpm"
#	include "menu_paste.xpm"
#	include "menu_print.xpm"
#	include "menu_print_preview.xpm"
#	include "menu_redo.xpm"
#	include "menu_save.xpm"
#	include "menu_save_as.xpm"
#	include "menu_undo.xpm"
#	include "menu_insert_table.xpm"
#	include "menu_insert_graphic.xpm"
#	include "menu_insert_symbol.xpm"
#	include "menu_insert_hyperlink.xpm"
#	include "menu_insert_bookmark.xpm"
#	include "menu_help.xpm"
#	include "menu_text_center.xpm"
#	include "menu_text_justify.xpm"
#	include "menu_text_left.xpm"
#	include "menu_text_right.xpm"
#	include "menu_text_bold.xpm"
#	include "menu_text_italic.xpm"
#	include "menu_text_strikethrough.xpm"
#	include "menu_text_underline.xpm"
#	include "menu_text_overline.xpm"
#	include "menu_text_topline.xpm"
#	include "menu_text_bottomline.xpm"
#	include "menu_superscript.xpm"
#	include "menu_subscript.xpm"
#	include "menu_spellcheck.xpm"
#	include "menu_add_row.xpm"
#	include "menu_add_column.xpm"
#	include "menu_delete_row.xpm"
#	include "menu_delete_column.xpm"
#	include "menu_merge_cells.xpm"
#	include "menu_split_cells.xpm"
#	include "menu_revert.xpm"
#	include "menu_export.xpm"
#	include "menu_import.xpm"
#	include "menu_file-properties.xpm"
#	include "menu_print-setup.xpm"
#	include "menu_close.xpm"
#	include "menu_search.xpm"
#	include "menu_search_replace.xpm"
#	include "menu_delete.xpm"
#	include "menu_jump_to.xpm"
#	include "menu_preferences.xpm"
#	include "menu_exec.xpm"
#	include "menu_book.xpm"
#	include "menu_delete_table.xpm"
#	include "menu_font.xpm"
#	include "menu_credits.xpm"
#	include "menu_about.xpm"

#else

	// Declare each toolbar icon that we are building.

	// Please, keep this list alphabetically sorted since we are doing a binary search
	// at AP_Toolbar_Icons::_findIconDataByName
	DefineToolbarIcon(menu_about_xpm)
	DefineToolbarIcon(menu_add_column_xpm)
	DefineToolbarIcon(menu_add_row_xpm)
	DefineToolbarIcon(menu_book_xpm)
	DefineToolbarIcon(menu_close_xpm)
	DefineToolbarIcon(menu_copy_xpm)
	DefineToolbarIcon(menu_credits_xpm)
	DefineToolbarIcon(menu_cut_xpm)
	DefineToolbarIcon(menu_delete_column_xpm)
	DefineToolbarIcon(menu_delete_row_xpm)
	DefineToolbarIcon(menu_delete_table_xpm)
	DefineToolbarIcon(menu_delete_xpm)
	DefineToolbarIcon(menu_exec_xpm)
	DefineToolbarIcon(menu_exit_xpm)
	DefineToolbarIcon(menu_export_xpm)
	DefineToolbarIcon(menu_file_properties_xpm)
	DefineToolbarIcon(menu_font_xpm)
	DefineToolbarIcon(menu_help_xpm)
	DefineToolbarIcon(menu_import_xpm)
	DefineToolbarIcon(menu_insert_bookmark_xpm)
	DefineToolbarIcon(menu_insert_graphic_xpm)
	DefineToolbarIcon(menu_insert_hyperlink_xpm)
	DefineToolbarIcon(menu_insert_symbol_xpm)
	DefineToolbarIcon(menu_insert_table_xpm)
	DefineToolbarIcon(menu_jump_to_xpm)
	DefineToolbarIcon(menu_merge_cells_xpm)
	DefineToolbarIcon(menu_new_xpm)
	DefineToolbarIcon(menu_open_xpm)
	DefineToolbarIcon(menu_paste_xpm)
	DefineToolbarIcon(menu_preferences_xpm)
	DefineToolbarIcon(menu_print_preview_xpm)
	DefineToolbarIcon(menu_print_setup_xpm)
	DefineToolbarIcon(menu_print_xpm)
	DefineToolbarIcon(menu_redo_xpm)
	DefineToolbarIcon(menu_revert_xpm)
	DefineToolbarIcon(menu_save_as_xpm)
	DefineToolbarIcon(menu_save_xpm)
	DefineToolbarIcon(menu_search_replace_xpm)
	DefineToolbarIcon(menu_search_xpm)
	DefineToolbarIcon(menu_spellcheck_xpm)
	DefineToolbarIcon(menu_split_cells_xpm)
	DefineToolbarIcon(menu_subscript_xpm)
	DefineToolbarIcon(menu_superscript_xpm)
	DefineToolbarIcon(menu_text_bold_xpm)
	DefineToolbarIcon(menu_text_bottomline_xpm)
	DefineToolbarIcon(menu_text_center_xpm)
	DefineToolbarIcon(menu_text_italic_xpm)
	DefineToolbarIcon(menu_text_justify_xpm)
	DefineToolbarIcon(menu_text_left_xpm)
	DefineToolbarIcon(menu_text_overline_xpm)
	DefineToolbarIcon(menu_text_right_xpm)
	DefineToolbarIcon(menu_text_strikethrough_xpm)
	DefineToolbarIcon(menu_text_topline_xpm)
	DefineToolbarIcon(menu_text_underline_xpm)
	DefineToolbarIcon(menu_undo_xpm)
	DefineToolbarIcon(tb_1column_xpm)
	DefineToolbarIcon(tb_2column_xpm)
	DefineToolbarIcon(tb_3column_xpm)
	DefineToolbarIcon(tb_add_column_xpm)
	DefineToolbarIcon(tb_add_row_xpm)
	DefineToolbarIcon(tb_anchor)
	DefineToolbarIcon(tb_copy_xpm)
	DefineToolbarIcon(tb_cut_xpm)
	DefineToolbarIcon(tb_delete_column_xpm)
	DefineToolbarIcon(tb_delete_row_xpm)
	DefineToolbarIcon(tb_edit_editfooter_xpm)
	DefineToolbarIcon(tb_edit_editheader_xpm)
	DefineToolbarIcon(tb_edit_removefooter_xpm)
	DefineToolbarIcon(tb_edit_removeheader_xpm)
	DefineToolbarIcon(tb_edit_xpm)
	DefineToolbarIcon(tb_help_xpm)
	DefineToolbarIcon(tb_hyperlink_xpm)
	DefineToolbarIcon(tb_insert_graphic_xpm)
	DefineToolbarIcon(tb_insert_table_xpm)
	DefineToolbarIcon(tb_line_double_space_xpm)
	DefineToolbarIcon(tb_line_middle_space_xpm)
	DefineToolbarIcon(tb_line_single_space_xpm)
	DefineToolbarIcon(tb_LineAll_xpm)
	DefineToolbarIcon(tb_LineBottom_xpm)
	DefineToolbarIcon(tb_LineLeft_xpm)
	DefineToolbarIcon(tb_LineNone_xpm)
	DefineToolbarIcon(tb_LineRight_xpm)
	DefineToolbarIcon(tb_LineTop_xpm)
	DefineToolbarIcon(tb_lists_bullets_xpm)
	DefineToolbarIcon(tb_lists_numbers_xpm)
	DefineToolbarIcon(tb_merge_cells_xpm)
	DefineToolbarIcon(tb_MergeAbove_xpm)
	DefineToolbarIcon(tb_MergeBelow_xpm)
	DefineToolbarIcon(tb_MergeLeft_xpm)
	DefineToolbarIcon(tb_MergeRight_xpm)
	DefineToolbarIcon(tb_new_xpm)
	DefineToolbarIcon(tb_open_xpm)
	DefineToolbarIcon(tb_para_0before_xpm)
	DefineToolbarIcon(tb_para_12before_xpm)
	DefineToolbarIcon(tb_paste_xpm)
	DefineToolbarIcon(tb_print_preview_xpm)
	DefineToolbarIcon(tb_print_xpm)
	DefineToolbarIcon(tb_redo_xpm)
	DefineToolbarIcon(tb_remove_graphic_xpm)
	DefineToolbarIcon(tb_save_as_xpm)
	DefineToolbarIcon(tb_save_xpm)
	DefineToolbarIcon(tb_script_play_xpm)
	DefineToolbarIcon(tb_smiley)
	DefineToolbarIcon(tb_spellcheck_xpm)
	DefineToolbarIcon(tb_split_cells_xpm)
	DefineToolbarIcon(tb_SplitAbove_xpm)
	DefineToolbarIcon(tb_SplitBelow_xpm)
	DefineToolbarIcon(tb_SplitHoriMid_xpm)
	DefineToolbarIcon(tb_SplitLeft_xpm)
	DefineToolbarIcon(tb_SplitRight_xpm)	
	DefineToolbarIcon(tb_SplitVertMid_xpm)
	DefineToolbarIcon(tb_stock_font_xpm)
	DefineToolbarIcon(tb_stock_paint_xpm)
	DefineToolbarIcon(tb_symbol_xpm)
	DefineToolbarIcon(tb_text_align_left_xpm)
	DefineToolbarIcon(tb_text_align_right_xpm)
	DefineToolbarIcon(tb_text_bgcolor_xpm)
	DefineToolbarIcon(tb_text_bold_xpm)
	DefineToolbarIcon(tb_text_bottomline_xpm)
	DefineToolbarIcon(tb_text_center_xpm)
	DefineToolbarIcon(tb_text_direction_ltr_xpm)
	DefineToolbarIcon(tb_text_direction_rtl_xpm)
	DefineToolbarIcon(tb_text_dom_direction_rtl_xpm)
	DefineToolbarIcon(tb_text_fgcolor_xpm)
	DefineToolbarIcon(tb_text_font_xpm)
	DefineToolbarIcon(tb_text_indent_xpm)
	DefineToolbarIcon(tb_text_italic_xpm)
	DefineToolbarIcon(tb_text_justify_xpm)
	DefineToolbarIcon(tb_text_overline_xpm)
	DefineToolbarIcon(tb_text_strikeout_xpm)
	DefineToolbarIcon(tb_text_subscript_xpm)
	DefineToolbarIcon(tb_text_superscript_xpm)
	DefineToolbarIcon(tb_text_topline_xpm)
	DefineToolbarIcon(tb_text_underline_xpm)
	DefineToolbarIcon(tb_text_unindent_xpm)
	DefineToolbarIcon(tb_todo_xpm)
	DefineToolbarIcon(tb_transparent_xpm)
	DefineToolbarIcon(tb_undo_xpm)
	DefineToolbarIcon(tb_view_full_screen_xpm)
	DefineToolbarIcon(tb_view_showpara_xpm)
	DefineToolbarIcon(tb_WrapButton_xpm)


	// these are specific to one or more translations

	// ... also add new icons here ...

#endif

==> abiword_2.9.2.orig.tar.gz: abiword-2.9.2/src/wp/ap/xp/ap_Toolbar_Icons_All.h <==
/* AbiWord
 * Copyright (C) 1998-2000 AbiSource, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */


/*****************************************************************
******************************************************************
** IT IS IMPORTANT THAT THIS FILE ALLOW ITSELF TO BE INCLUDED
** MORE THAN ONE TIME.
******************************************************************
*****************************************************************/

/*****************************************************************
******************************************************************
** FOR EACH ICON YOU ADD, ADD IT TO BOTH SECTIONS OF THIS FILE. **
******************************************************************
*****************************************************************/

#ifndef AP_TOOLBAR_ICONS_ALL_H

#	define AP_TOOLBAR_ICONS_ALL_H

	// Include each toolbar icon that we want to build.

#   include "tb_LineTop.xpm"
#   include "tb_LineBottom.xpm"
#   include "tb_LineLeft.xpm"
#   include "tb_LineRight.xpm"
#   include "tb_LineNone.xpm"
#   include "tb_LineAll.xpm"
#   include "tb_MergeAbove.xpm"
#   include "tb_MergeBelow.xpm"
#   include "tb_MergeLeft.xpm"
#   include "tb_MergeRight.xpm"
#   include "tb_SplitAbove.xpm"
#   include "tb_SplitVertMid.xpm"
#   include "tb_SplitBelow.xpm"
#   include "tb_SplitLeft.xpm"
#   include "tb_SplitHoriMid.xpm"
#   include "tb_SplitRight.xpm"
#	include "tb_text_center.xpm"
#	include "tb_text_justify.xpm"
#	include "tb_text_align_left.xpm"
#	include "tb_text_align_right.xpm"
#	include "tb_text_bold.xpm"
#	include "tb_text_font.xpm"
#	include "tb_text_italic.xpm"
#	include "tb_text_strikeout.xpm"
#	include "tb_text_underline.xpm"
#	include "tb_text_overline.xpm"
#	include "tb_text_topline.xpm"
#	include "tb_text_bottomline.xpm"
#	include "tb_text_superscript.xpm"
#	include "tb_text_subscript.xpm"
#	include "tb_help.xpm"
#	include "tb_text_direction_rtl.xpm"
#	include "tb_text_direction_ltr.xpm"
#	include "tb_text_dom_direction_rtl.xpm"
#	include "tb_symbol.xpm"
#	include "tb_para_0before.xpm"
#	include "tb_para_12before.xpm"
#	include "tb_1column.xpm"
#	include "tb_2column.xpm"
#	include "tb_3column.xpm"
#	include "tb_line_single_space.xpm"
#	include "tb_line_middle_space.xpm"
#	include "tb_line_double_space.xpm"
#	include "tb_copy.xpm"
#	include "tb_cut.xpm"
#	include "tb_edit.xpm"
#	include "tb_new.xpm"
#	include "tb_open.xpm"
#	include "tb_paste.xpm"
#	include "tb_print.xpm"
#	include "tb_print_preview.xpm"
#	include "tb_redo.xpm"
#	include "tb_save.xpm"
#	include "tb_save_as.xpm"
#	include "tb_undo.xpm"
#	include "tb_todo.xpm"
#	include "tb_lists_bullets.xpm"
#	include "tb_lists_numbers.xpm"
#	include "tb_text_indent.xpm"
#	include "tb_text_unindent.xpm"
#	include "tb_spellcheck.xpm"
#	include "tb_insert_graphic.xpm"
#	include "tb_remove_graphic.xpm"
#	include "tb_view_showpara.xpm"
#	include "tb_text_fgcolor.xpm"
#	include "tb_text_bgcolor.xpm"
#	include "tb_edit_editheader.xpm"
#	include "tb_edit_editfooter.xpm"
#	include "tb_edit_removeheader.xpm"
#	include "tb_edit_removefooter.xpm"
#	include "tb_anchor.xpm"
#	include "tb_hyperlink.xpm"
#	include "tb_smiley.xpm"

#	include "tb_script_play.xpm"
#	include "tb_stock_paint.xpm"

#	include "tb_insert_table.xpm"
#	include "tb_add_row.xpm"
#	include "tb_add_column.xpm"
#	include "tb_delete_row.xpm"
#	include "tb_delete_column.xpm"
#	include "tb_merge_cells.xpm"
#	include "tb_split_cells.xpm"
#	include "tb_transparent.xpm"
#	include "tb_WrapButton.xpm"
#       include "tb_stock_font.xpm"
#	include "tb_view_full_screen.xpm"

#	include "tb_revision_new.xpm"
#	include "tb_revision_select.xpm"
#	include "tb_revision_show_final.xpm"
#	include "tb_revision_find_prev.xpm"
#	include "tb_revision_find_next.xpm"


	// ... add new icons here (don't forget to add below the #else) ...

#	include "menu_copy.xpm"
#	include "menu_cut.xpm"
#	include "menu_exit.xpm"
#	include "menu_new.xpm"
#	include "menu_open.xpm"
#	include "menu_paste.xpm"
#	include "menu_print.xpm"
#	include "menu_print_preview.xpm"
#	include "menu_redo.xpm"
#	include "menu_save.xpm"
#	include "menu_save_as.xpm"
#	include "menu_undo.xpm"
#	include "menu_insert_table.xpm"
#	include "menu_insert_graphic.xpm"
#	include "menu_insert_symbol.xpm"
#	include "menu_insert_hyperlink.xpm"
#	include "menu_insert_bookmark.xpm"
#	include "menu_help.xpm"
#	include "menu_text_center.xpm"
#	include "menu_text_justify.xpm"
#	include "menu_text_left.xpm"
#	include "menu_text_right.xpm"
#	include "menu_text_bold.xpm"
#	include "menu_text_italic.xpm"
#	include "menu_text_strikethrough.xpm"
#	include "menu_text_underline.xpm"
#	include "menu_text_overline.xpm"
#	include "menu_text_topline.xpm"
#	include "menu_text_bottomline.xpm"
#	include "menu_superscript.xpm"
#	include "menu_subscript.xpm"
#	include "menu_spellcheck.xpm"
#	include "menu_add_row.xpm"
#	include "menu_add_column.xpm"
#	include "menu_delete_row.xpm"
#	include "menu_delete_column.xpm"
#	include "menu_merge_cells.xpm"
#	include "menu_split_cells.xpm"
#	include "menu_revert.xpm"
#	include "menu_export.xpm"
#	include "menu_import.xpm"
#	include "menu_file-properties.xpm"
#	include "menu_print-setup.xpm"
#	include "menu_close.xpm"
#	include "menu_search.xpm"
#	include "menu_search_replace.xpm"
#	include "menu_delete.xpm"
#	include "menu_jump_to.xpm"
#	include "menu_preferences.xpm"
#	include "menu_exec.xpm"
#	include "menu_book.xpm"
#	include "menu_delete_table.xpm"
#	include "menu_font.xpm"
#	include "menu_credits.xpm"
#	include "menu_about.xpm"

#else

	// Declare each toolbar icon that we are building.

	// Please, keep this list alphabetically sorted since we are doing a binary search
	// at AP_Toolbar_Icons::_findIconDataByName
	DefineToolbarIcon(menu_about_xpm)
	DefineToolbarIcon(menu_add_column_xpm)
	DefineToolbarIcon(menu_add_row_xpm)
	DefineToolbarIcon(menu_book_xpm)
	DefineToolbarIcon(menu_close_xpm)
	DefineToolbarIcon(menu_copy_xpm)
	DefineToolbarIcon(menu_credits_xpm)
	DefineToolbarIcon(menu_cut_xpm)
	DefineToolbarIcon(menu_delete_column_xpm)
	DefineToolbarIcon(menu_delete_row_xpm)
	DefineToolbarIcon(menu_delete_table_xpm)
	DefineToolbarIcon(menu_delete_xpm)
	DefineToolbarIcon(menu_exec_xpm)
	DefineToolbarIcon(menu_exit_xpm)
	DefineToolbarIcon(menu_export_xpm)
	DefineToolbarIcon(menu_file_properties_xpm)
	DefineToolbarIcon(menu_font_xpm)
	DefineToolbarIcon(menu_help_xpm)
	DefineToolbarIcon(menu_import_xpm)
	DefineToolbarIcon(menu_insert_bookmark_xpm)
	DefineToolbarIcon(menu_insert_graphic_xpm)
	DefineToolbarIcon(menu_insert_hyperlink_xpm)
	DefineToolbarIcon(menu_insert_symbol_xpm)
	DefineToolbarIcon(menu_insert_table_xpm)
	DefineToolbarIcon(menu_jump_to_xpm)
	DefineToolbarIcon(menu_merge_cells_xpm)
	DefineToolbarIcon(menu_new_xpm)
	DefineToolbarIcon(menu_open_xpm)
	DefineToolbarIcon(menu_paste_xpm)
	DefineToolbarIcon(menu_preferences_xpm)
	DefineToolbarIcon(menu_print_preview_xpm)
	DefineToolbarIcon(menu_print_setup_xpm)
	DefineToolbarIcon(menu_print_xpm)
	DefineToolbarIcon(menu_redo_xpm)
	DefineToolbarIcon(menu_revert_xpm)
	DefineToolbarIcon(menu_save_as_xpm)
	DefineToolbarIcon(menu_save_xpm)
	DefineToolbarIcon(menu_search_replace_xpm)
	DefineToolbarIcon(menu_search_xpm)
	DefineToolbarIcon(menu_spellcheck_xpm)
	DefineToolbarIcon(menu_split_cells_xpm)
	DefineToolbarIcon(menu_subscript_xpm)
	DefineToolbarIcon(menu_superscript_xpm)
	DefineToolbarIcon(menu_text_bold_xpm)
	DefineToolbarIcon(menu_text_bottomline_xpm)
	DefineToolbarIcon(menu_text_center_xpm)
	DefineToolbarIcon(menu_text_italic_xpm)
	DefineToolbarIcon(menu_text_justify_xpm)
	DefineToolbarIcon(menu_text_left_xpm)
	DefineToolbarIcon(menu_text_overline_xpm)
	DefineToolbarIcon(menu_text_right_xpm)
	DefineToolbarIcon(menu_text_strikethrough_xpm)
	DefineToolbarIcon(menu_text_topline_xpm)
	DefineToolbarIcon(menu_text_underline_xpm)
	DefineToolbarIcon(menu_undo_xpm)
	DefineToolbarIcon(tb_1column_xpm)
	DefineToolbarIcon(tb_2column_xpm)
	DefineToolbarIcon(tb_3column_xpm)
	DefineToolbarIcon(tb_add_column_xpm)
	DefineToolbarIcon(tb_add_row_xpm)
	DefineToolbarIcon(tb_anchor)
	DefineToolbarIcon(tb_copy_xpm)
	DefineToolbarIcon(tb_cut_xpm)
	DefineToolbarIcon(tb_delete_column_xpm)
	DefineToolbarIcon(tb_delete_row_xpm)
	DefineToolbarIcon(tb_edit_editfooter_xpm)
	DefineToolbarIcon(tb_edit_editheader_xpm)
	DefineToolbarIcon(tb_edit_removefooter_xpm)
	DefineToolbarIcon(tb_edit_removeheader_xpm)
	DefineToolbarIcon(tb_edit_xpm)
	DefineToolbarIcon(tb_help_xpm)
	DefineToolbarIcon(tb_hyperlink_xpm)
	DefineToolbarIcon(tb_insert_graphic_xpm)
	DefineToolbarIcon(tb_insert_table_xpm)
	DefineToolbarIcon(tb_line_double_space_xpm)
	DefineToolbarIcon(tb_line_middle_space_xpm)
	DefineToolbarIcon(tb_line_single_space_xpm)
	DefineToolbarIcon(tb_LineAll_xpm)
	DefineToolbarIcon(tb_LineBottom_xpm)
	DefineToolbarIcon(tb_LineLeft_xpm)
	DefineToolbarIcon(tb_LineNone_xpm)
	DefineToolbarIcon(tb_LineRight_xpm)
	DefineToolbarIcon(tb_LineTop_xpm)
	DefineToolbarIcon(tb_lists_bullets_xpm)
	DefineToolbarIcon(tb_lists_numbers_xpm)
	DefineToolbarIcon(tb_merge_cells_xpm)
	DefineToolbarIcon(tb_MergeAbove_xpm)
	DefineToolbarIcon(tb_MergeBelow_xpm)
	DefineToolbarIcon(tb_MergeLeft_xpm)
	DefineToolbarIcon(tb_MergeRight_xpm)
	DefineToolbarIcon(tb_new_xpm)
	DefineToolbarIcon(tb_open_xpm)
	DefineToolbarIcon(tb_para_0before_xpm)
	DefineToolbarIcon(tb_para_12before_xpm)
	DefineToolbarIcon(tb_paste_xpm)
	DefineToolbarIcon(tb_print_preview_xpm)
	DefineToolbarIcon(tb_print_xpm)
	DefineToolbarIcon(tb_redo_xpm)
	DefineToolbarIcon(tb_remove_graphic_xpm)
	DefineToolbarIcon(tb_revision_find_next_xpm)
	DefineToolbarIcon(tb_revision_find_prev_xpm)
	DefineToolbarIcon(tb_revision_new_xpm)
	DefineToolbarIcon(tb_revision_select_xpm)
	DefineToolbarIcon(tb_revision_show_final_xpm)
	DefineToolbarIcon(tb_save_as_xpm)
	DefineToolbarIcon(tb_save_xpm)
	DefineToolbarIcon(tb_script_play_xpm)
	DefineToolbarIcon(tb_smiley)
	DefineToolbarIcon(tb_spellcheck_xpm)
	DefineToolbarIcon(tb_split_cells_xpm)
	DefineToolbarIcon(tb_SplitAbove_xpm)
	DefineToolbarIcon(tb_SplitBelow_xpm)
	DefineToolbarIcon(tb_SplitHoriMid_xpm)
	DefineToolbarIcon(tb_SplitLeft_xpm)
	DefineToolbarIcon(tb_SplitRight_xpm)	
	DefineToolbarIcon(tb_SplitVertMid_xpm)
	DefineToolbarIcon(tb_stock_font_xpm)
	DefineToolbarIcon(tb_stock_paint_xpm)
	DefineToolbarIcon(tb_symbol_xpm)
	DefineToolbarIcon(tb_text_align_left_xpm)
	DefineToolbarIcon(tb_text_align_right_xpm)
	DefineToolbarIcon(tb_text_bgcolor_xpm)
	DefineToolbarIcon(tb_text_bold_xpm)
	DefineToolbarIcon(tb_text_bottomline_xpm)
	DefineToolbarIcon(tb_text_center_xpm)
	DefineToolbarIcon(tb_text_direction_ltr_xpm)
	DefineToolbarIcon(tb_text_direction_rtl_xpm)
	DefineToolbarIcon(tb_text_dom_direction_rtl_xpm)
	DefineToolbarIcon(tb_text_fgcolor_xpm)
	DefineToolbarIcon(tb_text_font_xpm)
	DefineToolbarIcon(tb_text_indent_xpm)
	DefineToolbarIcon(tb_text_italic_xpm)
	DefineToolbarIcon(tb_text_justify_xpm)
	DefineToolbarIcon(tb_text_overline_xpm)
	DefineToolbarIcon(tb_text_strikeout_xpm)
	DefineToolbarIcon(tb_text_subscript_xpm)
	DefineToolbarIcon(tb_text_superscript_xpm)
	DefineToolbarIcon(tb_text_topline_xpm)
	DefineToolbarIcon(tb_text_underline_xpm)
	DefineToolbarIcon(tb_text_unindent_xpm)
	DefineToolbarIcon(tb_todo_xpm)
	DefineToolbarIcon(tb_transparent_xpm)
	DefineToolbarIcon(tb_undo_xpm)
	DefineToolbarIcon(tb_view_full_screen_xpm)
	DefineToolbarIcon(tb_view_showpara_xpm)
	DefineToolbarIcon(tb_WrapButton_xpm)


	// these are specific to one or more translations

	// ... also add new icons here ...

#endif
